@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2017-01-11'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2017-01-13'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -127,6 +127,7 @@ sub _process_module {
 sub _process_script {
     require File::Temp;
     require Perinci::CmdLine::POD;
+    require Perinci::CmdLine::Util;
     #require Require::Hook::DzilBuild; # script is dumped in a different process, so doesn't work here
 
     my ($self, $document, $input) = @_;
@@ -143,19 +144,41 @@ sub _process_script {
         $filename = $tempname;
     }
 
+    (my $command_name = $input->{filename}) =~ s!.+/!!;
+
+    my $det_res = Perinci::CmdLine::Util::detect_pericmd_script(
+        filename => $filename,
+    );
+    if ($det_res->[0] == 412) {
+        $self->log_debug(["skipped file '%s' (%s)", $filename, $det_res->[1]]);
+        return;
+    } elsif (!$det_res->[2]) {
+        $self->log_debug(["skipped file '%s' (not detected as Perinci::CmdLine script)", $filename]);
+        return;
+    }
+
     # so scripts can know that they are being dumped in the context of
     # Dist::Zilla
     local $ENV{DZIL} = 1;
 
+    my $completer_name = $command_name;
+    if ($det_res->[3]{'func.is_inline'}) {
+        (my $comp_filename = $input->{filename}) =~ s!(.+)/(.+)!$1/_$2!;
+        my $has_completer = grep { $_->name eq $comp_filename }
+            @{ $input->{zilla}->files };
+        if ($has_completer) {
+            $completer_name = "_$command_name";
+        } else {
+            $completer_name = undef;
+        }
+    }
     my $res = Perinci::CmdLine::POD::gen_pod_for_pericmd_script(
         script => $filename,
-        );
-    if ($res->[0] == 412) {
-        $self->log_debug(["skipped file '%s' (%s)", $filename, $res->[1]]);
-        return;
-    } elsif ($res->[0] != 200) {
-        die "Can't generate POD for script: $res->[0] - $res->[1]";
-    }
+        program_name => $command_name,
+        (completer_script => $completer_name) x !!defined($completer_name),
+    );
+    die "Can't generate POD for script: $res->[0] - $res->[1]"
+        unless $res->[0] == 200;
 
     my $modified;
     for my $s (@{ $res->[3]{'func.sections'} }) {
@@ -222,7 +245,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.73 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2017-01-11.
+This document describes version 0.74 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2017-01-13.
 
 =head1 SYNOPSIS
 
